flask-project-templates
=======================

This package contains templates for creating Flask projects layouts.

Templates:
----------

* flask_base: Flask basic project

Installation:
-------------

From GitHub (latest revision):
******************************

    pip install git+https://github.com/mattoufoutu/flask-project-templates.git

From PyPI:
**********

    pip install flask-project-templates
